==> resolwe-bio-1.2.0.tar.gz: resolwe-bio-1.2.0/resolwe_bio/tests/processes/test_demultiplex.py <==
# pylint: disable=missing-docstring
from resolwe_bio.utils.test import BioProcessTestCase
from resolwe.flow.models import Data



class DemultiplexProcessorTestCase(BioProcessTestCase):

    def test_demultiplex(self):
        inputs = {
            'reads': 'pool24.read1.small.qseq.bz2',
            'reads2': 'pool24.read3.small.qseq.bz2',
            'barcodes': 'pool24.read2.small.qseq.bz2',
            'annotation': 'pool24.tsv'
        }
        obj = self.run_processor('upload-multiplexed-paired', inputs)
        self.assertFields(obj, 'matched', '5 reads (7.04 %)')
        self.assertFields(obj, 'notmatched', '51 reads (71.83 %)')
        self.assertFields(obj, 'badquality', '13 reads (18.31 %)')
        self.assertFields(obj, 'skipped', '0 reads (0.00 %)')

        reads = Data.objects.last()
        self.assertFiles(reads, "fastq", ["demultiplexed_reads_fw.fastq.gz"], compression='gzip')
        self.assertFiles(reads, "fastq2", ["demultiplexed_reads_rw.fastq.gz"], compression='gzip')

        inputs = {
            'reads': 'pool24.read3.small.qseq.bz2',
            'reads2': 'pool24.read1.small.qseq.bz2',
            'barcodes': 'pool24.read2.small.qseq.bz2',
            'annotation': 'pool24.tsv'
        }
        obj = self.run_processor('upload-multiplexed-paired', inputs)
        self.assertFields(obj, 'matched', '5 reads (7.04 %)')
        self.assertFields(obj, 'notmatched', '51 reads (71.83 %)')
        self.assertFields(obj, 'badquality', '13 reads (18.31 %)')
        self.assertFields(obj, 'skipped', '0 reads (0.00 %)')

        inputs = {
            'reads': 'pool24.read1.small.qseq.bz2',
            'reads2': 'pool24.read3.small.qseq.bz2',
            'barcodes': 'pool24.read2.small.qseq.bz2',
            'annotation': 'pool24.2.tsv'
        }
        obj = self.run_processor('upload-multiplexed-paired', inputs)
        self.assertFields(obj, 'matched', '5 reads (7.04 %)')
        self.assertFields(obj, 'notmatched', '51 reads (71.83 %)')
        self.assertFields(obj, 'badquality', '13 reads (18.31 %)')
        self.assertFields(obj, 'skipped', '0 reads (0.00 %)')

        inputs = {
            'reads': 's_1_1.qseq.small.txt.bz2',
            'reads2': 's_1_3.qseq.small.txt.bz2',
            'barcodes': 's_1_2.qseq.small.txt.bz2',
            'annotation': 's_1.tsv'
        }
        obj = self.run_processor('upload-multiplexed-paired', inputs)
        self.assertFields(obj, 'matched', '12 reads (11.88 %)')
        self.assertFields(obj, 'notmatched', '80 reads (79.21 %)')
        self.assertFields(obj, 'badquality', '8 reads (7.92 %)')
        self.assertFields(obj, 'skipped', '0 reads (0.00 %)')

==> resolwe-bio-3.0.0.tar.gz: resolwe-bio-3.0.0/resolwe_bio/tests/processes/test_demultiplex.py <==
# pylint: disable=missing-docstring
from resolwe_bio.utils.test import BioProcessTestCase
from resolwe.flow.models import Data


class DemultiplexProcessorTestCase(BioProcessTestCase):

    def test_demultiplex(self):
        inputs = {
            'reads': 'pool24.read1.small.qseq.bz2',
            'reads2': 'pool24.read3.small.qseq.bz2',
            'barcodes': 'pool24.read2.small.qseq.bz2',
            'annotation': 'pool24.tsv'
        }
        obj = self.run_process('upload-multiplexed-paired', inputs)
        self.assertFields(obj, 'matched', '5 reads (7.04 %)')
        self.assertFields(obj, 'notmatched', '51 reads (71.83 %)')
        self.assertFields(obj, 'badquality', '13 reads (18.31 %)')
        self.assertFields(obj, 'skipped', '0 reads (0.00 %)')

        reads = Data.objects.last()
        self.assertFiles(reads, "fastq", ["demultiplexed_reads_fw.fastq.gz"], compression='gzip')
        self.assertFiles(reads, "fastq2", ["demultiplexed_reads_rw.fastq.gz"], compression='gzip')

        inputs = {
            'reads': 'pool24.read3.small.qseq.bz2',
            'reads2': 'pool24.read1.small.qseq.bz2',
            'barcodes': 'pool24.read2.small.qseq.bz2',
            'annotation': 'pool24.tsv'
        }
        obj = self.run_process('upload-multiplexed-paired', inputs)
        self.assertFields(obj, 'matched', '5 reads (7.04 %)')
        self.assertFields(obj, 'notmatched', '51 reads (71.83 %)')
        self.assertFields(obj, 'badquality', '13 reads (18.31 %)')
        self.assertFields(obj, 'skipped', '0 reads (0.00 %)')

        inputs = {
            'reads': 'pool24.read1.small.qseq.bz2',
            'reads2': 'pool24.read3.small.qseq.bz2',
            'barcodes': 'pool24.read2.small.qseq.bz2',
            'annotation': 'pool24.2.tsv'
        }
        obj = self.run_process('upload-multiplexed-paired', inputs)
        self.assertFields(obj, 'matched', '5 reads (7.04 %)')
        self.assertFields(obj, 'notmatched', '51 reads (71.83 %)')
        self.assertFields(obj, 'badquality', '13 reads (18.31 %)')
        self.assertFields(obj, 'skipped', '0 reads (0.00 %)')

        inputs = {
            'reads': 's_1_1.qseq.small.txt.bz2',
            'reads2': 's_1_3.qseq.small.txt.bz2',
            'barcodes': 's_1_2.qseq.small.txt.bz2',
            'annotation': 's_1.tsv'
        }
        obj = self.run_process('upload-multiplexed-paired', inputs)
        self.assertFields(obj, 'matched', '12 reads (11.88 %)')
        self.assertFields(obj, 'notmatched', '80 reads (79.21 %)')
        self.assertFields(obj, 'badquality', '8 reads (7.92 %)')
        self.assertFields(obj, 'skipped', '0 reads (0.00 %)')
